

<h1 align = "center">:rocket: 傻瓜式建模 :facepunch:</h1>

---
## [auto_ml][1]
## [tpot][2]
## [auto-sklearn][3]
## [MLBox][4]
## [hyperopt-sklearn][5]
## [sklearn-porter][6]
## [经验参数][7]
## [autokeras][8]
---
[1]: https://github.com/ClimbsRocks/auto_ml
[2]: https://github.com/rhiever/tpot
[3]: https://github.com/automl/auto-sklearn
[4]: https://github.com/AxeldeRomblay/MLBox
[5]: https://github.com/hyperopt/hyperopt-sklearn
[6]: https://github.com/nok/sklearn-porter
[7]: https://www.leiphone.com/news/201705/hVff8ZQz0pdSfRv5.html
[8]: https://github.com/jhfjhfj1/autokeras
